@@ -49,7 +49,10 @@
 #include "maptile-loader.h"
 #include "maptile-module-manager.h"
 
-#define MAPTILE_REPO_CONF "~/.maptile-loader/ecoach-maptile-loader.conf"
+#define MAPTILE_REPO_CONF "/usr/share/ecoach-maptile-loader/ecoach-maptile-loader.conf"
+#define DATA_DIR ".ecoach"
+#define MAP_DIR "Maps"
+#define MAP_TYPE "OpenStreet"
 
 /* DBUS definitions and RPC methods */
 const gchar * MAPTILE_LOADER_DBUS_SERVICE = "org.ecoach.maptileloader";
@@ -58,6 +61,7 @@ const gchar * MAPTILE_LOADER_DBUS_INTERFACE = "org.ecoach.maptileloader";
 
 const gchar * MAPTILE_LOADER_FUNCTION_GET_SUPPORTED_MAPS = "MaptileLoaderGetSupportedMaps";
 const gchar * MAPTILE_LOADER_FUNCTION_GET_MAPTILE = "MaptileLoaderGetMaptile";
+const gchar * MAPTILE_LOADER_TERMINATE = "MaptileLoaderTerminate";
 
 /* Module manager handles plugins */
 static MaptileModuleManager *module_manager = NULL;
@@ -124,6 +128,18 @@ static void signalmanager(int sig)
     exit(0);
 }
 
+/* Get user homedir path */
+static char* get_homedir(){
+
+   char homedir[256] = {0,};
+   char *tmp = getenv("HOME");
+    if(tmp) {
+      strncpy(homedir, tmp, sizeof(homedir));
+      homedir[sizeof(homedir) - 1] = '\0';
+    }
+   return homedir;
+}
+
 /* Main function */
 int main( void )
 {
@@ -340,7 +356,16 @@ static gboolean maptile_loader_init_repos()
 
         g_debug("Creating repo for maptile %s", groups[i]);
 
-        cache = g_key_file_get_string(repo_file, groups[i], "cache", NULL);
+
+	const char *const homedir = get_homedir();
+
+       // const char key = g_key_file_get_string(repo_file, groups[i], "cache", NULL);
+	const char *datadir = DATA_DIR;
+	const char *mapdir = MAP_DIR;
+	const char *maptype = MAP_TYPE;
+
+	 asprintf(&cache, "%s/%s/%s/%s", homedir,datadir,mapdir,maptype);
+
 
         /* Check for existence of the cache URI */
         GnomeVFSURI *map_dir_uri = gnome_vfs_uri_new(cache);
@@ -458,7 +483,12 @@ dbus_cb_default(DBusConnection *connection, DBusMessage *message, void *user_dat
 {
     DBusHandlerResult res = DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
     DBusMessage * reply = NULL;
-
+    
+    if (dbus_message_is_method_call(message, MAPTILE_LOADER_DBUS_INTERFACE, MAPTILE_LOADER_TERMINATE) )
+    {
+	signalmanager(9);
+    }
+    
     if (dbus_message_is_method_call(message, MAPTILE_LOADER_DBUS_INTERFACE, MAPTILE_LOADER_FUNCTION_GET_MAPTILE) )
     {
         gchar *maptype;
@@ -513,7 +543,7 @@ dbus_cb_default(DBusConnection *connection, DBusMessage *message, void *user_dat
     {
         res = DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
     }
-
+  
     /* Send the reply */
     if (reply)
     {
